Types for building flag-based APIs and functionality
Structs
- AllSet
- Iterator over all set feature flags
- Filtered
Iter - Iterator over a filtered set feature flags
- FlagRef
- Keeps a reference to a specific feature flag within
FlagVecvector - FlagVec
- Bit flag vector. Can hold up to 2^16-1 flags and guaranteed to have length up to 255 bytes.
- Parse
Error - Error parsing feature vector string representation: only
1,0,+,-,*,!,#,_and whitespace characters are allowed
Type Aliases
- FlagNo
- A single feature flag, represented by it’s number inside feature vector