pub struct u6(/* private fields */);Expand description
6-bit unsigned integer in the range 0..64
Implementations
Sourceimpl u6
impl u6
Sourceimpl u6
impl u6
Sourcepub fn checked_add<T>(self, rhs: T) -> Option<u6>
pub fn checked_add<T>(self, rhs: T) -> Option<u6>
Checked integer addition. Computes self + rhs, returning None if
overflow occurred.
Sourcepub fn saturating_add<T>(self, rhs: T) -> u6
pub fn saturating_add<T>(self, rhs: T) -> u6
Saturating integer addition. Computes self + rhs, saturating at the
numeric bounds instead of overflowing.
Sourcepub fn overflowing_add<T>(self, rhs: T) -> (u6, bool)
pub fn overflowing_add<T>(self, rhs: T) -> (u6, bool)
Calculates self + rhs
Returns a tuple of the addition along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.
Sourcepub fn wrapping_add<T>(self, rhs: T) -> u6
pub fn wrapping_add<T>(self, rhs: T) -> u6
Wrapping (modular) addition. Computes self + rhs, wrapping around at
the boundary of the type.
Sourcepub fn checked_sub<T>(self, rhs: T) -> Option<u6>
pub fn checked_sub<T>(self, rhs: T) -> Option<u6>
Checked integer subtraction. Computes self - rhs, returning None if
overflow occurred.
Sourcepub fn saturating_sub<T>(self, rhs: T) -> u6
pub fn saturating_sub<T>(self, rhs: T) -> u6
Saturating integer subtraction. Computes self - rhs, saturating at the
numeric bounds instead of overflowing.
Sourcepub fn overflowing_sub<T>(self, rhs: T) -> (u6, bool)
pub fn overflowing_sub<T>(self, rhs: T) -> (u6, bool)
Calculates self - rhs
Returns a tuple of the subtraction along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.
Sourcepub fn wrapping_sub<T>(self, rhs: T) -> u6
pub fn wrapping_sub<T>(self, rhs: T) -> u6
Wrapping (modular) subtraction. Computes self - rhs, wrapping around at
the boundary of the type.
Sourcepub fn checked_mul<T>(self, rhs: T) -> Option<u6>
pub fn checked_mul<T>(self, rhs: T) -> Option<u6>
Checked integer multiplication. Computes self * rhs, returning None if
overflow occurred.
Sourcepub fn saturating_mul<T>(self, rhs: T) -> u6
pub fn saturating_mul<T>(self, rhs: T) -> u6
Saturating integer multiplication. Computes self * rhs, saturating at the
numeric bounds instead of overflowing.
Sourcepub fn overflowing_mul<T>(self, rhs: T) -> (u6, bool)
pub fn overflowing_mul<T>(self, rhs: T) -> (u6, bool)
Calculates self * rhs
Returns a tuple of the multiplication along with a boolean indicating whether an arithmetic overflow would occur. If an overflow would have occurred then the wrapped value is returned.
Sourcepub fn wrapping_mul<T>(self, rhs: T) -> u6
pub fn wrapping_mul<T>(self, rhs: T) -> u6
Wrapping (modular) multiplication. Computes self * rhs, wrapping around at
the boundary of the type.
pub fn div_rem(self, other: u6) -> Result<(u6, u6), DivError>