pub trait WrapperMut: Wrapper {
// Required method
fn as_inner_mut(&mut self) -> &mut Self::Inner;
}Expand description
Trait allowing mutable reference borrowing for the wrapped inner type.
Required Methods
Sourcefn as_inner_mut(&mut self) -> &mut Self::Inner
fn as_inner_mut(&mut self) -> &mut Self::Inner
Returns a mutable reference to the inner representation for the wrapper type
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".