Bytes

Type Alias Bytes 

pub type Bytes<const LEN: usize> = Array<u8, LEN>;
Wrapper type for all array-based bytes implementing many important traits, so types based on it can simply derive their implementations.

Type keeps data in little-endian byte order and displays them in the same order (like bitcoin SHA256 single hash type).

Aliased Type

pub struct Bytes<const LEN: usize>(/* private fields */);