Bytes16

Type Alias Bytes16 

pub type Bytes16 = Array<u8, 16>;
Wrapper type for all array-based 128-bit types implementing many important traits, so types based on it can simply derive their implementations.

Type keeps data in little-endian byte order and displays them in the same order (like bitcoin SHA256 single hash type).

Aliased Type

pub struct Bytes16(/* private fields */);