Bytes32StrRev

Type Alias Bytes32StrRev 

pub type Bytes32StrRev = Array<u8, 32, true>;
Wrapper type for all array-based 256-bit types implementing many important traits, so types based on it can simply derive their implementations.

Type keeps data in little-endian byte order and displays them in the revers (like bitcoin SHA256d hash types).

Aliased Type

pub struct Bytes32StrRev(/* private fields */);