pub trait RawArray<const LEN: usize>: Sized {
// Required methods
fn from_raw_array(val: impl Into<[u8; LEN]>) -> Self;
fn to_raw_array(&self) -> [u8; LEN];
}๐Deprecated since 4.2.0:
use ByteArray instead
Trait which does a blanket implementation for all types wrapping Arrays
Required Methods
Sourcefn from_raw_array(val: impl Into<[u8; LEN]>) -> Self
๐Deprecated since 4.2.0: use ByteArray instead
fn from_raw_array(val: impl Into<[u8; LEN]>) -> Self
use ByteArray instead
Constructs a wrapper type around an array.
Sourcefn to_raw_array(&self) -> [u8; LEN]
๐Deprecated since 4.2.0: use ByteArray instead
fn to_raw_array(&self) -> [u8; LEN]
use ByteArray instead
Returns a raw array representation stored in the wrapped type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".