pub type Bytes20 = Array<u8, 20>;Expand description
Wrapper type for all array-based 160-bit types implementing many important traits, so types based on it can simply derive their implementations.
Type keeps data in little-endian byte order and displays them in the same order (like bitcoin SHA256 single hash type).
Aliased Type
pub struct Bytes20(/* private fields */);